<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns="http://www.w3.org/1999/xhtml"
    xmlns:html="http://www.w3.org/1999/xhtml"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:wwmode="urn:WebWorks-Engine-Mode"
    xmlns:wwdoc="urn:WebWorks-Document-Schema"
    xmlns:wwsplits="urn:WebWorks-Engine-Splits-Schema"
    xmlns:wwproject="urn:WebWorks-Publish-Project"
    xmlns:wwlog="urn:WebWorks-XSLT-Extension-Log"
    xmlns:wwprojext="urn:WebWorks-XSLT-Extension-Project"
    xmlns:wwexsldoc="urn:WebWorks-XSLT-Extension-Document"
    exclude-result-prefixes="xsl wwmode wwdoc wwproject wwlog wwprojext wwexsldoc"
    >
    
    <xsl:template match="wwdoc:Paragraph[@stylename = '2col Container Open']" mode="wwmode:content">
        <wwexsldoc:Text disable-output-escaping="yes">
            <xsl:text>&lt;div class="simple_list" columns="2"&gt;</xsl:text>
        </wwexsldoc:Text>
    </xsl:template>
    
    <xsl:template match="wwdoc:Paragraph[@stylename = '2col Container Close']" mode="wwmode:content">
        <wwexsldoc:Text disable-output-escaping="yes">
            <xsl:text>&lt;/div&gt;</xsl:text>
        </wwexsldoc:Text>
    </xsl:template>
    
    <xsl:template match="wwdoc:Paragraph[@stylename = '3col Container Open']" mode="wwmode:content">
        <wwexsldoc:Text disable-output-escaping="yes">
            <xsl:text>&lt;div class="simple_list" columns="3"&gt;</xsl:text>
        </wwexsldoc:Text>
    </xsl:template>
    
    <xsl:template match="wwdoc:Paragraph[@stylename = '3col Container Close']" mode="wwmode:content">
        <wwexsldoc:Text disable-output-escaping="yes">
            <xsl:text>&lt;/div&gt;</xsl:text>
        </wwexsldoc:Text>
    </xsl:template>
    
    <!-- Global variable to get column count -->
    <xsl:variable name="columns" select="number(/div/@columns)"/>
    
    <!-- Match the context node -->
    <xsl:template match="div[@class='simple_list']">
        <table>
            <!-- Match items in the 1st, 4th, 7th positions, etc (or whatever the column variable holds) -->
            <xsl:apply-templates select="div[@class='Simple_List_1'][position() mod $columns = 1]"/>
        </table>
    </xsl:template>
    
    <xsl:template match="div[@class='Simple_List_1']">
        <tr>
            <!-- Output the current item -->
            <td>
                <xsl:value-of select="."/>
            </td>
            <!-- Output the following items based on the number of required columns -->
            <xsl:for-each select="following-sibling::div[@class='Simple_List_1'][position() &lt; $columns]">
                <td>
                    <xsl:value-of select="."/>
                </td>
            </xsl:for-each>
            <!-- Add in any empty cells if numberof following items is not sufficient -->
            <xsl:call-template name="emptycell">
                <xsl:with-param name="cellcounter" select="count(following-sibling::div[@class='Simple_List_1'][position() &lt; $columns]) + 1" />
            </xsl:call-template>
        </tr>
    </xsl:template>
    
    <!-- Recursive template to add in empty cells when there are not enough items to complete a row -->
    <xsl:template name="emptycell">
        <xsl:param name="cellcounter" />
        <xsl:if test="$cellcounter &lt; $columns">
            <td></td>
            <xsl:call-template name="emptycell">
                <xsl:with-param name="cellcounter" select="$cellcounter + 1" />
            </xsl:call-template>
        </xsl:if>   
    </xsl:template>
    
</xsl:stylesheet>
